searchData={"items":[{"type":"module","title":"Localize.PhoenixRuntime","doc":"This module provides:\n\n- A Plug (`plug/3`) to update the connection with locale attributes and store them\n  in the session.\n- A LiveView lifecycle hook (`handle_params/4`) to update the socket with\n  locale attributes.\n\nBoth are optimized for performance.\n\nLocale values can be sourced independently from locations like:\n\n- Pre-compiled route attributes\n- The `Accept-Language` header sent by the client (`fr-CH, fr;q=0.9, en;q=0.8, de;q=0.7`)\n- Query parameters (`?lang=fr`)\n- Hostname (`fr.example.com`)\n- Path parameters (`/fr/products`)\n- Assigns (`assign(socket, [locale: \"fr\"])`)\n- Body parameters\n- Stored cookie\n- Session data\n\n\nRuntime detection is configured by specifying sources for locale attributes\n(`:locale`, `:language`, `:region`).\n\n#### Locale Attributes and Their Sources\n\nEach attribute (`:locale`, `:language`, `:region`) can have its own list of\nsources and parameter names, where the parameter name is the key to get from\nthe source. The parameter should be provided as a string.\n\n##### Supported Sources\n- `:accept_language`: From the header sent by the client (e.g. `fr-CH, fr;q=0.9, en;q=0.8, de;q=0.7`)\n- `:assigns`: From conn and socket assigns.\n- `:attrs`: From precompiled route attributes.\n- `:body`: From request body parameters.\n- `:cookie`: From request cookies.\n- `:host`: From the hostname (e.g., `en.example.com`).\n- `:path`: From path parameters (e.g., `/:lang/users`).\n- `:query`: From query parameters (e.g., `?locale=de`).\n- `:session`: From session data.\n\n##### Default Configuration\n\nThe default sources for each attribute are:\n`[:query, :session, :cookie, :accept_language, :path, :attrs]`.\n\n##### Overriding Detection Behavior\n\nYou can customize sources and parameters per attribute:\n\n**Examples:**\n```elixir\n# In your config module\nlocale_sources: [:query, :session, :accept_language], # Order matters\nlocale_params: [\"locale\"], # Look for ?locale=... etc\n\nlanguage_sources: [:path, :host],\nlanguage_params: [\"lang\"], # Look for /:lang/... etc\n\nregion_sources: [:attrs] # Only use region from extra provided attributes\n# region_params defaults to [\"region\"]\n```","ref":"Localize.PhoenixRuntime.html"},{"type":"function","title":"Localize.PhoenixRuntime.call/3","doc":"Plug callback to detect and assign locale attributes to the connection.\n\nExamines configured sources (params, session, headers, etc.), updates\n`conn.assigns`, merges attributes into `conn.private.loc`, and\npersists relevant attributes in the session.","ref":"Localize.PhoenixRuntime.html#call/3"},{"type":"type","title":"Localize.PhoenixRuntime.conn/0","doc":"","ref":"Localize.PhoenixRuntime.html#t:conn/0"},{"type":"function","title":"Localize.PhoenixRuntime.handle_params/4","doc":"LiveView `handle_params/4` callback hook.\n\nDetects locale settings based on URL, params, and socket state, then updates\nthe socket assigns and Localize attributes.","ref":"Localize.PhoenixRuntime.html#handle_params/4"},{"type":"type","title":"Localize.PhoenixRuntime.params/0","doc":"","ref":"Localize.PhoenixRuntime.html#t:params/0"},{"type":"type","title":"Localize.PhoenixRuntime.plug_opts/0","doc":"","ref":"Localize.PhoenixRuntime.html#t:plug_opts/0"},{"type":"type","title":"Localize.PhoenixRuntime.socket/0","doc":"","ref":"Localize.PhoenixRuntime.html#t:socket/0"},{"type":"type","title":"Localize.PhoenixRuntime.url/0","doc":"","ref":"Localize.PhoenixRuntime.html#t:url/0"},{"type":"module","title":"Localize.PhoenixRuntime.Attrs","doc":"Provides an interface to access and update Localize attributes\nin sockets, or connections (hereinafter `containers`).","ref":"Localize.PhoenixRuntime.Attrs.html"},{"type":"type","title":"Localize.PhoenixRuntime.Attrs.attrs_fun/0","doc":"","ref":"Localize.PhoenixRuntime.Attrs.html#t:attrs_fun/0"},{"type":"type","title":"Localize.PhoenixRuntime.Attrs.container/0","doc":"","ref":"Localize.PhoenixRuntime.Attrs.html#t:container/0"},{"type":"function","title":"Localize.PhoenixRuntime.Attrs.get/3","doc":"Retrieves the value for `key` from the container's attributes, or returns `default`.\n\nWhen no key is provided, returns the entire attributes map.","ref":"Localize.PhoenixRuntime.Attrs.html#get/3"},{"type":"function","title":"Localize.PhoenixRuntime.Attrs.get!/3","doc":"Retrieves the value for `key` from the container's attributes.\n\nRaises an error (with an optional custom message) if the key is not found.","ref":"Localize.PhoenixRuntime.Attrs.html#get!/3"},{"type":"type","title":"Localize.PhoenixRuntime.Attrs.key/0","doc":"","ref":"Localize.PhoenixRuntime.Attrs.html#t:key/0"},{"type":"function","title":"Localize.PhoenixRuntime.Attrs.merge/2","doc":"Merges the given value into the container's attributes.\n\nThe value can be either a list of key-value pairs or a map.","ref":"Localize.PhoenixRuntime.Attrs.html#merge/2"},{"type":"function","title":"Localize.PhoenixRuntime.Attrs.private?/1","doc":"Returns true if the given key or attribute tuple represents a private attribute.\n\nA private attribute is one whose name starts with `\"__\"`.","ref":"Localize.PhoenixRuntime.Attrs.html#private?/1"},{"type":"function","title":"Localize.PhoenixRuntime.Attrs.put/2","doc":"Replaces the container's attributes with the provided map.","ref":"Localize.PhoenixRuntime.Attrs.html#put/2"},{"type":"function","title":"Localize.PhoenixRuntime.Attrs.put/3","doc":"Assigns `value` to `key` in the container's attributes.","ref":"Localize.PhoenixRuntime.Attrs.html#put/3"},{"type":"type","title":"Localize.PhoenixRuntime.Attrs.t/0","doc":"","ref":"Localize.PhoenixRuntime.Attrs.html#t:t/0"},{"type":"function","title":"Localize.PhoenixRuntime.Attrs.update/2","doc":"Updates the container's attributes by applying the given function.\n\nThe function receives the current attributes map and must return an enumerable,\nwhich is then converted into a new map.","ref":"Localize.PhoenixRuntime.Attrs.html#update/2"},{"type":"function","title":"Localize.PhoenixRuntime.Attrs.update/3","doc":"Updates the value assigned to `key` in the container's attributes by applying the given function.","ref":"Localize.PhoenixRuntime.Attrs.html#update/3"},{"type":"type","title":"Localize.PhoenixRuntime.Attrs.update_fun/0","doc":"","ref":"Localize.PhoenixRuntime.Attrs.html#t:update_fun/0"},{"type":"type","title":"Localize.PhoenixRuntime.Attrs.value/0","doc":"","ref":"Localize.PhoenixRuntime.Attrs.html#t:value/0"},{"type":"module","title":"Localize.PhoenixRuntime.Compat","doc":"Compatibility functions","ref":"Localize.PhoenixRuntime.Compat.html"},{"type":"function","title":"Localize.PhoenixRuntime.Compat.assign_module/0","doc":"Returns the module to use for LiveView assignments","ref":"Localize.PhoenixRuntime.Compat.html#assign_module/0"},{"type":"module","title":"Localize.PhoenixRuntime.Detector","doc":"Main module for locale detection logic.","ref":"Localize.PhoenixRuntime.Detector.html"},{"type":"function","title":"Localize.PhoenixRuntime.Detector.detect_locales/3","doc":"","ref":"Localize.PhoenixRuntime.Detector.html#detect_locales/3"},{"type":"module","title":"Localize.PhoenixRuntime.Extractor","doc":"Extracts locale information from various sources. Handles both `Plug.Conn`\nstructs and map inputs.\n\nSupports languages and regions defined in the [IANA Language Subtag\nRegistry](https://www.iana.org/assignments/language-subtag-registry/language-subtag-registry)","ref":"Localize.PhoenixRuntime.Extractor.html"},{"type":"module","title":"Sources - Localize.PhoenixRuntime.Extractor","doc":"List of sources to examine for this field.\n\n* `:accept_language` examines the `accept-language` header.\n* `:attrs` uses the (precompiled) route atributes.\n* `:body` uses `body_params`; useful when using values in API bodies.\n* `:cookie` uses the request cookie(s)\n* `:host` examines the hostname e.g `en.example.com` and `example.nl`. Returns the first match..\n* `:path` uses `path_params` such as `/:locale/products/`\n* `:query` uses `query_params` such as `/products?locale=en-US`\n* `:session` uses the session\n* `:assigns` uses the assigns stored in connection of socket","ref":"Localize.PhoenixRuntime.Extractor.html#module-sources"},{"type":"module","title":"Params - Localize.PhoenixRuntime.Extractor","doc":"List of keys in a source to examine. Defaults to the name of the field with\nfallback to `locale`.","ref":"Localize.PhoenixRuntime.Extractor.html#module-params"},{"type":"function","title":"Localize.PhoenixRuntime.Extractor.extract_from_source/4","doc":"","ref":"Localize.PhoenixRuntime.Extractor.html#extract_from_source/4"},{"type":"module","title":"Localize.PhoenixRuntime.Parser","doc":"Handles parsing of accept-language headers.\nUses efficient binary pattern matching and follows RFC 5646 BCP 47 language tag format.","ref":"Localize.PhoenixRuntime.Parser.html"},{"type":"function","title":"Localize.PhoenixRuntime.Parser.parse_accept_language/1","doc":"Parses an accept-language header into a list of locale entries.","ref":"Localize.PhoenixRuntime.Parser.html#parse_accept_language/1"},{"type":"function","title":"Examples - Localize.PhoenixRuntime.Parser.parse_accept_language/1","doc":"iex> parse_accept_language(\"en-US,fr-FR;q=0.8\")\n    [\n      %{language: \"en\", region: \"US\", territory: \"US\", locale: \"en-US\", quality: 1.0},\n      %{language: \"fr\", region: \"FR\", territory: \"FR\", locale: \"fr-FR\", quality: 0.8}\n    ]","ref":"Localize.PhoenixRuntime.Parser.html#parse_accept_language/1-examples"},{"type":"module","title":"Localize.PhoenixRuntime.Types","doc":"Type definitions for locale detection.","ref":"Localize.PhoenixRuntime.Types.html"},{"type":"type","title":"Localize.PhoenixRuntime.Types.attrs/0","doc":"","ref":"Localize.PhoenixRuntime.Types.html#t:attrs/0"},{"type":"type","title":"Localize.PhoenixRuntime.Types.locale_entry/0","doc":"","ref":"Localize.PhoenixRuntime.Types.html#t:locale_entry/0"},{"type":"type","title":"Localize.PhoenixRuntime.Types.locale_key/0","doc":"","ref":"Localize.PhoenixRuntime.Types.html#t:locale_key/0"},{"type":"type","title":"Localize.PhoenixRuntime.Types.locale_result/0","doc":"","ref":"Localize.PhoenixRuntime.Types.html#t:locale_result/0"},{"type":"type","title":"Localize.PhoenixRuntime.Types.source/0","doc":"","ref":"Localize.PhoenixRuntime.Types.html#t:source/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}